# xnatio
xnatio, which runs inside the of jupyter notebook, is a program designed for gathering a presenting useful summary statistics from the [XNAT](https://xnat.org) database. My vision for the project is that it will be highly customizable, allowing users to interface with data of any xsi:type--even if xnatio does not understand what that data represents. There will also be a range of pre-selected queries to generate useful information.

I am completing this project during my employment as a summer student in the Neuroinformatics Research Group at Washington University in St. Louis.
